
import "rushl.Horsey.ui";


HorseyBar = class( rushl.Horsey.ui.SimpleWindow );

function HorseyBar:Constructor()
	rushl.Horsey.ui.SimpleWindow.Constructor( self );
	
	self.spacing = 5;
	self.quickslotCount = 0;
	self.quickslotSize = 36;
	self.quickslots = { };
	self.quickslotInfo = { };
	
	
	self.menuButton = Turbine.UI.Control()
	self.menuButton:SetParent( self );
	self.menuButton:SetBackground( "rushl/Horsey/Resources/DownArrow.tga" );
	self.menuButton:SetSize( 14, 13 );
	
	
	self.menuButton.MouseDown = function( sender, args )
		local contextMenu = Turbine.UI.ContextMenu()
		
		local sizeMenu = Turbine.UI.MenuItem( "Size" );
		local sizeMenuItems = sizeMenu:GetItems();
		
		local i;
		
		for i = 1, 30, 1 do
			local sizeItem = Turbine.UI.MenuItem( tostring( i ) );
			
			if ( self.quickslotCount == i ) then
				sizeItem:SetChecked( true );
			end
			
			sizeItem.Click = function( sender, args )
				local newCount = tonumber( sender:GetText() );
				self:SetQuickslotCount( newCount );
				self.settings.QuickslotCount = newCount;
				QuickslotCountSave = self.settings.QuickslotCount
				self:SaveSettings();
			end
			
			sizeMenuItems:Add( sizeItem );
		end
		
		local contextMenuItems = contextMenu:GetItems();
		contextMenuItems:Add( sizeMenu );
		contextMenu:ShowMenu();
	end
	
	self:LoadSettings();
	
	self:SetQuickslotCount( self.settings.QuickslotCount );
	
	--This line displays the number of available slots:
	--Turbine.Shell.WriteLine("Count:".. self.quickslotCount);
	
	self:SetVisible( true );
	self:SetOpacity( 1 );
	self:SetBackColor( Turbine.UI.Color( .6, .5, .7, .5) );
	
	--self:FireBar();
	
end

function HorseyBar:LoadSettings()
	self.settings = Turbine.PluginData.Load( Turbine.DataScope.Character, "Horsey4OtherBarSettings" );

	if ( type( self.settings ) ~= "table" ) then
		self.settings = { };
	end

	if ( not self.settings.QuickslotCount ) then
		self.settings.QuickslotCount = 5;
	end
	
	if ( not self.settings.positionX ) then
		self.settings.positionX = 500;
	end
	
	if ( not self.settings.positionY ) then
		self.settings.positionY = 500;
	end
	
	QuickslotCountSave = self.settings.QuickslotCount	
	FirebarpositionX = self.settings.positionX;
	FirebarpositionY = self.settings.positionY;
	
	self.quickslotInfo = Turbine.PluginData.Load( Turbine.DataScope.Character, "Horsey4Other" );

	if ( type( self.quickslotInfo ) ~= "table" ) then
		self.quickslotInfo = { };
	end

	
end

function HorseyBar:SaveSettings()
	self.settings = { };
	self.settings.QuickslotCount = QuickslotCountSave;
	self.settings.positionX = FirebarpositionX;
	self.settings.positionY = FirebarpositionY;
	
	Turbine.PluginData.Save( Turbine.DataScope.Character, "Horsey4OtherBarSettings", self.settings );
			--Turbine.Shell.WriteLine(FirebarpositionX.." x "..FirebarpositionY);
			--Turbine.Shell.WriteLine("Saving...");
end

function HorseyBar:SetQuickslotCount( value )
	local oldCount = self.quickslotCount;
	local newCount = value;
	local i;
	
	self.quickslotCount = value;

	randquickslotCount = self.quickslotCount
	randquickslotInfo = self.quickslotInfo
	
	-- Remove any quickslots no longer required.
	for i = newCount + 1, oldCount, 1 do
		self.quickslots[i]:SetVisible( false );
		self.quickslots[i]:SetParent( nil );
		self.quickslots[i] = nil;
	end
	
	local function OnQuickslotChanged( sender, args )
		local shortcut = sender:GetShortcut();

		if ( shortcut ~= nil ) then
			self.quickslotInfo[sender.Index] = { };
			self.quickslotInfo[sender.Index].Type = shortcut:GetType();
			self.quickslotInfo[sender.Index].Data= shortcut:GetData();
		else
			self.quickslotInfo[sender.Index] = nil;
		end

		if ( self.loading ) then
			return;
		end

		-- Request for the quickslot info table to be saved.
		Turbine.PluginData.Save( Turbine.DataScope.Character, "Horsey4Other", self.quickslotInfo );
	end
		
	-- Add any new quickslots that should be created.
	for i = oldCount + 1, newCount, 1 do
		self.quickslots[i] = Turbine.UI.Lotro.Quickslot();
		self.quickslots[i]:SetParent( self );
		self.quickslots[i]:SetSize( self.quickslotSize, self.quickslotSize );
		self.quickslots[i]:SetPosition( ( i - 1 ) * ( self.quickslotSize + self.spacing ), 0 );
		self.quickslots[i].Index = i;
		self.quickslots[i].ShortcutChanged = OnQuickslotChanged;

		local quickslotInfo = self.quickslotInfo[i];

		if ( quickslotInfo ~= nil ) then
			local shortcut = Turbine.UI.Lotro.Shortcut( quickslotInfo.Type, quickslotInfo.Data );
			self.quickslots[i]:SetShortcut( shortcut );
		end
		
		--Give a way to remove a filled slot
			self.quickslots[i].MouseClick = function( sender, args )
				if(args.Button == Turbine.UI.MouseButton.Right) then
					self.quickslots[i]:SetShortcut( nil );
					HorseyWindow:SetVisible( false );
				end
			end
		
	end

	local displayWidth = Turbine.UI.Display:GetWidth();
	local displayHeight = Turbine.UI.Display:GetHeight();

	local width = self.quickslotCount * self.quickslotSize + ( self.quickslotCount - 1 ) * self.spacing;

	self:SetSize( width, self.quickslotSize + 22 );
	self:SetPosition( ( displayWidth - width ) / 2, displayHeight * 2 / 3 );

	self.menuButton:SetPosition( ( width - self.menuButton:GetWidth() ) / 2, self.quickslotSize + 2 );


	
end

	-- create the launcher window
function HorseyBar:FireBar()

	self.positionX = FirebarpositionX;
	self.positionY = FirebarpositionY;	

	FireWindow = Turbine.UI.Lotro.Window();
	FireWindow:SetWidth(240);
	FireWindow:SetPosition( self.positionX, self.positionY);
	FireWindow:SetText("Horsey for Other!");
	FireQuickslot = Turbine.UI.Lotro.Quickslot();
	FireQuickslot:SetParent(FireWindow);
	FireQuickslot:SetSize(36, 36);
	FireQuickslot:SetPosition(110, 40);

	
	FireQuickslot.MouseClick = function( sender, args )
    FireWindow:SetVisible( false );
	end
	
	
	--Figure out how many slots are filled
	local MaxRand = randquickslotCount;
	local i;
	local failsafe = 0
	
		-- Take out check value	
	--Turbine.Shell.WriteLine("Count:".. MaxRand);
	
	--Assign one to the Fire Window
	repeat
	i = math.random(1, MaxRand);
	
			--Turbine.Shell.WriteLine("Random: ".. i)
			
	local quickslotInfo = randquickslotInfo[i];
	
	
	if ( quickslotInfo ~= nil ) then
	
		local checktype = randquickslotInfo[i].Type
	
		--Turbine.Shell.WriteLine("incoming type: ".. checktype)
		
			if checktype == 6 then
				-- Take out check value
				--Turbine.Shell.WriteLine("Assigned: ".. i)
				--Turbine.Shell.WriteLine("incoming type: ".. checktype)
			
				local shortcut = Turbine.UI.Lotro.Shortcut( randquickslotInfo[i].Type, randquickslotInfo[i].Data );
				FireQuickslot:SetShortcut( shortcut );
				checksuccess = true;
			else
				--Turbine.Shell.WriteLine("skipped");
				checksuccess = false;
			end
	
	else
		--Turbine.Shell.WriteLine("blank");
		checksuccess = false;
		
	end
	
	failsafe = failsafe + 1;
		-- Take out check value
		--Turbine.Shell.WriteLine("Failsafe: ".. failsafe)
	
	until failsafe == 100 or checksuccess == true;

	
	
	FireWindow.PositionChanged = function( sender, args )
		local x,y = FireWindow:GetPosition();
		FirebarpositionX = x;
		FirebarpositionY = y;
		
		--Turbine.Shell.WriteLine(FirebarpositionX.." x "..FirebarpositionY);
		--HorseyBar:SaveSettings();
		self:SaveSettings();
	end
	
	--old test code
	
	--Turbine.Shell.WriteLine( self.quickslotInfo[3].Type.." ".. self.quickslotInfo[3].Data )
	--Turbine.Shell.WriteLine("Count:".. self.quickslotCount);
end







